| Home | Libraries | People | FAQ | More

### Sinus Cardinal and Hyperbolic Sinus Cardinal Functions Overview

The Sinus Cardinal family of functions (indexed by the family of indices `a > 0`) is defined by

it sees heavy use in signal processing tasks.

By analogy, the Hyperbolic Sinus Cardinal family of functions (also indexed by the family of indices `a > 0`) is defined by

These two families of functions are composed of entire functions.

These functions (sinc_pi and sinhc_pi) are needed by our implementation of quaternions and octonions.

> Sinus Cardinal of index pi (purple) and Hyperbolic Sinus Cardinal of index pi (red) on R